# Devices

[Kaithemautomation Index](./README.md#kaithemautomation-index) / Devices

> Auto-generated documentation for [devices](../../../api/devices.py) module.

#### Attributes

- `all_devices` - Use all_devices[DevName] or for i in all_devices to get device objects.
  Devices will be iot_devices Device class objects.: _devices.DeviceNamespace()
- [Devices](#devices)
